
Requirements
------------

PyPlanet runs on Python 3.6 and later. Most linux distributions contain default packages or will come with Python
preinstalled. If you don't have Python 3.6 you can still continue the installation, we will help you through the installation
of Python 3.6 in our installation guides!

**Summary of requirements:**

* Python 3.6+ and pip 9.
* MySQL Server or PostgreSQL Server.
* Maniaplanet Dedicated (Maniaplanet 4 is minimum)


**Installation manuals:**

Please head to one of our installation manuals to continue:

:doc:`Linux Guide </intro/installation-linux>` or :doc:`Windows Guide </intro/installation-windows>`
